@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gTree.mli 1496 2010-01-14 15:38:03Z ben_99_9 $ *)
+(* $Id$ *)
 
 open Gobject
 open Gtk
@@ -305,6 +305,7 @@ class view_column : tree_view_column obj ->
     method alignment : float
     method clickable : bool
     method connect : view_column_signals
+    method expand : bool
     method fixed_width : int
     method get_sort_column_id : int
     method max_width : int
@@ -313,6 +314,7 @@ class view_column : tree_view_column obj ->
     method resizable : bool
     method set_alignment : float -> unit
     method set_clickable : bool -> unit
+    method set_expand : bool -> unit
     method set_fixed_width : int -> unit
     method set_max_width : int -> unit
     method set_min_width : int -> unit
@@ -371,6 +373,21 @@ class view_signals : [> tree_view] obj ->
       callback:(tree_iter -> tree_path -> bool) -> GtkSignal.id
     method toggle_cursor_row : callback:(unit -> bool) -> GtkSignal.id
     method unselect_all : callback:(unit -> bool) -> GtkSignal.id
+    method notify_enable_search : callback:(bool -> unit) -> GtkSignal.id
+    method notify_enable_tree_lines : callback:(bool -> unit) -> GtkSignal.id
+    method notify_enable_grid_lines :
+      callback:(GtkEnums.tree_view_grid_lines -> unit) -> GtkSignal.id
+    method notify_fixed_height_mode : callback:(bool -> unit) -> GtkSignal.id
+    method notify_hadjustment : callback:(GData.adjustment -> unit) -> GtkSignal.id
+    method notify_headers_visible : callback:(bool -> unit) -> GtkSignal.id
+    method notify_hover_expand : callback:(bool -> unit) -> GtkSignal.id
+    method notify_hover_selection : callback:(bool -> unit) -> GtkSignal.id
+    method notify_reorderable : callback:(bool -> unit) -> GtkSignal.id
+    method notify_rules_hint : callback:(bool -> unit) -> GtkSignal.id
+    method notify_search_column : callback:(int -> unit) -> GtkSignal.id
+    method notify_tooltip_column : callback:(int -> unit) -> GtkSignal.id
+    method notify_vadjustment :
+      callback:(GData.adjustment -> unit) -> GtkSignal.id
   end
 
 (** A widget for displaying both trees and lists
@@ -437,8 +454,16 @@ class view : tree_view obj ->
     method set_hover_expand : bool -> unit (** @since GTK 2.6 *)
     method hover_selection : bool (** @since GTK 2.6 *)
     method set_hover_selection : bool -> unit (** @since GTK 2.6 *)
-    method set_row_separator_func : (model -> tree_iter -> bool) option -> unit (** @since GTK 2.6 *)
-  end
+    method set_row_separator_func :
+        (model -> tree_iter -> bool) option -> unit (** @since GTK 2.6 *)
+    method enable_grid_lines : GtkEnums.tree_view_grid_lines
+        (** @since GTK 2.10 *)
+    method enable_tree_lines : bool (** @since GTK 2.10 *)
+    method set_enable_grid_lines : GtkEnums.tree_view_grid_lines -> unit
+        (** @since GTK 2.10 *)
+    method set_enable_tree_lines : bool -> unit
+        (** @since GTK 2.10 *)
+    end
 
 (** @gtkdoc gtk GtkTreeView *)
 val view :
@@ -558,9 +583,10 @@ class cell_renderer_pixbuf : Gtk.cell_renderer_pixbuf obj ->
   end
 
 (** @gtkdoc gtk GtkCellRendererText *)
-class cell_renderer_text_signals : Gtk.cell_renderer_text obj ->
+class cell_renderer_text_signals : ([>Gtk.cell_renderer_text] as 'a) obj ->
   object
     inherit GObj.gtkobj_signals
+    val obj : 'a obj
     method edited : callback:(Gtk.tree_path -> string -> unit) -> GtkSignal.id
   end
 
@@ -594,12 +620,22 @@ class cell_renderer_progress : Gtk.cell_renderer_progress obj ->
     method connect : GObj.gtkobj_signals_impl
   end
 
+(** @since GTK 2.6
+    @gtkdoc gtk GtkCellRendererCombo *)
+class cell_renderer_combo_signals : ([>Gtk.cell_renderer_combo] as 'a) obj ->
+  object
+    inherit cell_renderer_text_signals
+    val obj : 'a obj
+    method changed :
+      callback:(Gtk.tree_path -> Gtk.tree_iter -> unit) -> GtkSignal.id
+  end
+
 (** @since GTK 2.6
     @gtkdoc gtk GtkCellRendererCombo *)
 class cell_renderer_combo : Gtk.cell_renderer_combo obj ->
   object
     inherit[Gtk.cell_renderer_combo,cell_properties_combo] cell_renderer_skel
-    method connect : cell_renderer_text_signals
+    method connect : cell_renderer_combo_signals
     method set_fixed_height_from_font : int -> unit
   end
 
@@ -656,6 +692,14 @@ class icon_view_signals : [> Gtk.icon_view] Gtk.obj ->
     inherit GContainer.container_signals
     method item_activated : callback:(Gtk.tree_path -> unit) -> GtkSignal.id
     method selection_changed : callback:(unit -> unit) -> GtkSignal.id
+    method notify_column_spacing : callback:(int -> unit) -> GtkSignal.id
+    method notify_columns : callback:(int -> unit) -> GtkSignal.id
+    method notify_item_width : callback:(int -> unit) -> GtkSignal.id
+    method notify_margin : callback:(int -> unit) -> GtkSignal.id
+    method notify_orientation : callback:(GtkEnums.orientation -> unit) -> GtkSignal.id
+    method notify_row_spacing : callback:(int -> unit) -> GtkSignal.id
+    method notify_selection_mode : callback:(GtkEnums.selection_mode -> unit) -> GtkSignal.id
+    method notify_spacing : callback:(int -> unit) -> GtkSignal.id
   end
 
 (** A widget which displays a list of icons in a grid
@@ -693,7 +737,7 @@ class icon_view :
     method spacing : int
     method set_spacing : int -> unit
 
-    method get_path_at_pos : int -> int -> Gtk.tree_path
+    method get_path_at_pos : int -> int -> Gtk.tree_path option
     method selected_foreach : (Gtk.tree_path -> unit) -> unit
     method get_selected_items : Gtk.tree_path list
     method path_is_selected : Gtk.tree_path -> bool
