@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gWindow.mli 1447 2009-03-19 14:41:16Z garrigue $ *)
+(* $Id$ *)
 
 open Gtk
 open GObj
@@ -191,9 +191,10 @@ class ['a] dialog_skel : ([>Gtk.dialog] as 'b) obj ->
 
 (** Create popup windows
    @gtkdoc gtk GtkDialog *)
-class ['a] dialog_ext : [> Gtk.dialog] obj ->
+class ['a] dialog_ext : ([> Gtk.dialog] as 'b) obj ->
   object
     inherit ['a] dialog_skel
+    val obj : 'b obj
     method add_button : string -> 'a -> unit
     method add_button_stock : GtkStock.id -> 'a -> unit
   end
@@ -203,6 +204,7 @@ class ['a] dialog_ext : [> Gtk.dialog] obj ->
 class ['a] dialog : [> Gtk.dialog] obj ->
   object
     inherit ['a] dialog_ext
+    val obj : Gtk.dialog obj
     method connect : 'a dialog_signals
   end
 
@@ -236,7 +238,6 @@ val dialog :
 type any_response = [GtkEnums.response | `OTHER of int]
 class dialog_any : [> Gtk.dialog] obj -> [any_response] dialog
 
-
 (** {3 GtkMessageDialog} *)
 
 type 'a buttons
@@ -584,7 +585,7 @@ class plug : Gtk.plug obj ->
 
 (** @gtkdoc gtk GtkPlug *)
 val plug :
-  window:Gdk.xid ->
+  window:Gdk.native_window ->
   ?border_width:int ->
   ?width:int -> ?height:int -> ?show:bool -> unit -> plug
 
@@ -606,7 +607,7 @@ class socket : Gtk.socket obj ->
     inherit GContainer.container
     val obj : Gtk.socket obj
     method connect : socket_signals
-    method steal : Gdk.xid -> unit
+    method steal : Gdk.native_window -> unit
     (** @deprecated "inherently unreliable" *)
     method xwindow : Gdk.xid
   end
