@@ -1,3 +1,7 @@
+/* platform : tags and macros */
+#define MLTAG_X11	((value)(4387128*2+1))
+#define MLTAG_WIN32	((value)(-933730405*2+1))
+#define MLTAG_QUARTZ	((value)(-13833829*2+1))
 /* event_type : tags and macros */
 #define MLTAG_NOTHING	((value)(-818712595*2+1))
 #define MLTAG_DELETE	((value)(492530731*2+1))
@@ -218,6 +222,10 @@ extern const lookup_info ml_table_join_style[];
 #define MLTAG_BUTTON3	((value)(-901175807*2+1))
 #define MLTAG_BUTTON4	((value)(-901175806*2+1))
 #define MLTAG_BUTTON5	((value)(-901175805*2+1))
+#define MLTAG_SUPER	((value)(44972379*2+1))
+#define MLTAG_HYPER	((value)(803910220*2+1))
+#define MLTAG_META	((value)(857346757*2+1))
+#define MLTAG_RELEASE	((value)(-658417241*2+1))
 
 extern const lookup_info ml_table_gdkModifier[];
 #define Val_gdkModifier(data) ml_lookup_from_c (ml_table_gdkModifier, data)
