@@ -47,6 +47,10 @@ module TreeView = struct
       {name="hover-expand"; conv=boolean}
     let hover_selection : ([>`treeview],_) property =
       {name="hover-selection"; conv=boolean}
+    let enable_grid_lines : ([>`treeview],_) property =
+      {name="enable-grid-lines"; conv=GtkEnums.tree_view_grid_lines_conv}
+    let enable_tree_lines : ([>`treeview],_) property =
+      {name="enable-tree-lines"; conv=boolean}
     let tooltip_column : ([>`treeview],_) property =
       {name="tooltip-column"; conv=int}
   end
@@ -386,6 +390,8 @@ module TreeViewColumn = struct
       {name="alignment"; conv=float}
     let clickable : ([>`treeviewcolumn],_) property =
       {name="clickable"; conv=boolean}
+    let expand : ([>`treeviewcolumn],_) property =
+      {name="expand"; conv=boolean}
     let fixed_width : ([>`treeviewcolumn],_) property =
       {name="fixed-width"; conv=int}
     let max_width : ([>`treeviewcolumn],_) property =
@@ -580,7 +586,8 @@ module IconView = struct
       {name="selection_changed"; classe=`iconview; marshaller=marshal_unit}
   end
   let create pl : Gtk.icon_view obj = Object.make "GtkIconView" pl
-  external get_path_at_pos : [>`iconview] obj -> int -> int -> Gtk.tree_path
+  external get_path_at_pos :
+    [>`iconview] obj -> int -> int -> Gtk.tree_path option
     = "ml_gtk_icon_view_get_path_at_pos"
   external selected_foreach :
     [>`iconview] obj -> (Gtk.tree_path -> unit) -> unit
