@@ -140,6 +140,17 @@ extern const lookup_info ml_table_menu_direction_type[];
 #define Val_menu_direction_type(data) ml_lookup_from_c (ml_table_menu_direction_type, data)
 #define Menu_direction_type_val(key) ml_lookup_to_c (ml_table_menu_direction_type, key)
 
+/* message_type : tags and macros */
+#define MLTAG_INFO	((value)(813432942*2+1))
+#define MLTAG_WARNING	((value)(161459772*2+1))
+#define MLTAG_QUESTION	((value)(3549990*2+1))
+#define MLTAG_ERROR	((value)(-250084440*2+1))
+#define MLTAG_OTHER	((value)(879009456*2+1))
+
+extern const lookup_info ml_table_message_type[];
+#define Val_message_type(data) ml_lookup_from_c (ml_table_message_type, data)
+#define Message_type_val(key) ml_lookup_to_c (ml_table_message_type, key)
+
 /* metric_type : tags and macros */
 #define MLTAG_PIXELS	((value)(1059887917*2+1))
 #define MLTAG_INCHES	((value)(-976305992*2+1))
@@ -154,6 +165,7 @@ extern const lookup_info ml_table_metric_type[];
 #define MLTAG_VISUAL_POSITIONS	((value)(-939942389*2+1))
 #define MLTAG_PAGES	((value)(993747748*2+1))
 #define MLTAG_BUFFER_ENDS	((value)(-1017891049*2+1))
+#define MLTAG_HORIZONTAL_PAGES	((value)(63037001*2+1))
 
 extern const lookup_info ml_table_movement_step[];
 #define Val_movement_step(data) ml_lookup_from_c (ml_table_movement_step, data)
@@ -253,7 +265,6 @@ extern const lookup_info ml_table_signal_run_type[];
 /* scroll_step : tags and macros */
 #define MLTAG_STEPS	((value)(33338247*2+1))
 #define MLTAG_HORIZONTAL_STEPS	((value)(-897372500*2+1))
-#define MLTAG_HORIZONTAL_PAGES	((value)(63037001*2+1))
 #define MLTAG_HORIZONTAL_ENDS	((value)(331551923*2+1))
 
 extern const lookup_info ml_table_scroll_step[];
@@ -366,6 +377,7 @@ extern const lookup_info ml_table_window_type[];
 /* wrap_mode : tags and macros */
 #define MLTAG_CHAR	((value)(746596054*2+1))
 #define MLTAG_WORD	((value)(968739274*2+1))
+#define MLTAG_WORD_CHAR	((value)(944880811*2+1))
 
 extern const lookup_info ml_table_wrap_mode[];
 #define Val_wrap_mode(data) ml_lookup_from_c (ml_table_wrap_mode, data)
@@ -379,6 +391,18 @@ extern const lookup_info ml_table_sort_type[];
 #define Val_sort_type(data) ml_lookup_from_c (ml_table_sort_type, data)
 #define Sort_type_val(key) ml_lookup_to_c (ml_table_sort_type, key)
 
+/* pack_direction : tags and macros */
+#define MLTAG_TTB	((value)(4196034*2+1))
+#define MLTAG_BTT	((value)(3300930*2+1))
+
+extern const lookup_info ml_table_pack_direction[];
+#define Val_pack_direction(data) ml_lookup_from_c (ml_table_pack_direction, data)
+#define Pack_direction_val(key) ml_lookup_to_c (ml_table_pack_direction, key)
+
+extern const lookup_info ml_table_tree_view_grid_lines[];
+#define Val_tree_view_grid_lines(data) ml_lookup_from_c (ml_table_tree_view_grid_lines, data)
+#define Tree_view_grid_lines_val(key) ml_lookup_to_c (ml_table_tree_view_grid_lines, key)
+
 /* cell_type : tags and macros */
 #define MLTAG_EMPTY	((value)(-305630611*2+1))
 #define MLTAG_PIXMAP	((value)(1060283293*2+1))
@@ -388,6 +412,30 @@ extern const lookup_info ml_table_cell_type[];
 #define Val_cell_type(data) ml_lookup_from_c (ml_table_cell_type, data)
 #define Cell_type_val(key) ml_lookup_to_c (ml_table_cell_type, key)
 
+/* text_window_type : tags and macros */
+#define MLTAG_PRIVATE	((value)(155386083*2+1))
+
+extern const lookup_info ml_table_text_window_type[];
+#define Val_text_window_type(data) ml_lookup_from_c (ml_table_text_window_type, data)
+#define Text_window_type_val(key) ml_lookup_to_c (ml_table_text_window_type, key)
+
+/* text_search_flag : tags and macros */
+#define MLTAG_VISIBLE_ONLY	((value)(-365153351*2+1))
+#define MLTAG_TEXT_ONLY	((value)(-357645954*2+1))
+
+extern const lookup_info ml_table_text_search_flag[];
+#define Val_text_search_flag(data) ml_lookup_from_c (ml_table_text_search_flag, data)
+#define Text_search_flag_val(key) ml_lookup_to_c (ml_table_text_search_flag, key)
+
+/* button_action : tags and macros */
+#define MLTAG_SELECTS	((value)(39343575*2+1))
+#define MLTAG_DRAGS	((value)(-576421409*2+1))
+#define MLTAG_EXPANDS	((value)(535917753*2+1))
+
+extern const lookup_info ml_table_button_action[];
+#define Val_button_action(data) ml_lookup_from_c (ml_table_button_action, data)
+#define Button_action_val(key) ml_lookup_to_c (ml_table_button_action, key)
+
 /* toolbar_child : tags and macros */
 #define MLTAG_SPACE	((value)(-11221850*2+1))
 #define MLTAG_TOGGLEBUTTON	((value)(-374054778*2+1))
@@ -404,6 +452,13 @@ extern const lookup_info ml_table_toolbar_space_style[];
 #define Val_toolbar_space_style(data) ml_lookup_from_c (ml_table_toolbar_space_style, data)
 #define Toolbar_space_style_val(key) ml_lookup_to_c (ml_table_toolbar_space_style, key)
 
+/* spin_button_update_policy : tags and macros */
+#define MLTAG_IF_VALID	((value)(-640747590*2+1))
+
+extern const lookup_info ml_table_spin_button_update_policy[];
+#define Val_spin_button_update_policy(data) ml_lookup_from_c (ml_table_spin_button_update_policy, data)
+#define Spin_button_update_policy_val(key) ml_lookup_to_c (ml_table_spin_button_update_policy, key)
+
 /* spin_type : tags and macros */
 #define MLTAG_HOME	((value)(802394655*2+1))
 #define MLTAG_USER_DEFINED	((value)(-593067403*2+1))
@@ -420,15 +475,6 @@ extern const lookup_info ml_table_accel_flag[];
 #define Val_accel_flag(data) ml_lookup_from_c (ml_table_accel_flag, data)
 #define Accel_flag_val(key) ml_lookup_to_c (ml_table_accel_flag, key)
 
-/* button_action : tags and macros */
-#define MLTAG_SELECTS	((value)(39343575*2+1))
-#define MLTAG_DRAGS	((value)(-576421409*2+1))
-#define MLTAG_EXPANDS	((value)(535917753*2+1))
-
-extern const lookup_info ml_table_button_action[];
-#define Val_button_action(data) ml_lookup_from_c (ml_table_button_action, data)
-#define Button_action_val(key) ml_lookup_to_c (ml_table_button_action, key)
-
 /* calendar_display_options : tags and macros */
 #define MLTAG_SHOW_HEADING	((value)(859563808*2+1))
 #define MLTAG_SHOW_DAY_NAMES	((value)(-1059042013*2+1))
@@ -474,29 +520,25 @@ extern const lookup_info ml_table_target_flags[];
 #define Val_target_flags(data) ml_lookup_from_c (ml_table_target_flags, data)
 #define Target_flags_val(key) ml_lookup_to_c (ml_table_target_flags, key)
 
-/* spin_button_update_policy : tags and macros */
-#define MLTAG_IF_VALID	((value)(-640747590*2+1))
-
-extern const lookup_info ml_table_spin_button_update_policy[];
-#define Val_spin_button_update_policy(data) ml_lookup_from_c (ml_table_spin_button_update_policy, data)
-#define Spin_button_update_policy_val(key) ml_lookup_to_c (ml_table_spin_button_update_policy, key)
-
 /* tree_view_mode : tags and macros */
 #define MLTAG_ITEM	((value)(813731091*2+1))
-/* text_window_type : tags and macros */
-#define MLTAG_PRIVATE	((value)(155386083*2+1))
+/* tree_model_flags : tags and macros */
+#define MLTAG_ITERS_PERSIST	((value)(-339514704*2+1))
+#define MLTAG_LIST_ONLY	((value)(-402526163*2+1))
 
-extern const lookup_info ml_table_text_window_type[];
-#define Val_text_window_type(data) ml_lookup_from_c (ml_table_text_window_type, data)
-#define Text_window_type_val(key) ml_lookup_to_c (ml_table_text_window_type, key)
+extern const lookup_info ml_table_tree_model_flags[];
+#define Val_tree_model_flags(data) ml_lookup_from_c (ml_table_tree_model_flags, data)
+#define Tree_model_flags_val(key) ml_lookup_to_c (ml_table_tree_model_flags, key)
 
-/* text_search_flag : tags and macros */
-#define MLTAG_VISIBLE_ONLY	((value)(-365153351*2+1))
-#define MLTAG_TEXT_ONLY	((value)(-357645954*2+1))
+/* tree_view_drop_position : tags and macros */
+#define MLTAG_BEFORE	((value)(-860553089*2+1))
+#define MLTAG_AFTER	((value)(462462460*2+1))
+#define MLTAG_INTO_OR_BEFORE	((value)(486315964*2+1))
+#define MLTAG_INTO_OR_AFTER	((value)(-475234977*2+1))
 
-extern const lookup_info ml_table_text_search_flag[];
-#define Val_text_search_flag(data) ml_lookup_from_c (ml_table_text_search_flag, data)
-#define Text_search_flag_val(key) ml_lookup_to_c (ml_table_text_search_flag, key)
+extern const lookup_info ml_table_tree_view_drop_position[];
+#define Val_tree_view_drop_position(data) ml_lookup_from_c (ml_table_tree_view_drop_position, data)
+#define Tree_view_drop_position_val(key) ml_lookup_to_c (ml_table_tree_view_drop_position, key)
 
 /* tree_view_column_sizing : tags and macros */
 #define MLTAG_GROW_ONLY	((value)(-657645480*2+1))
@@ -516,15 +558,9 @@ extern const lookup_info ml_table_cell_renderer_mode[];
 #define Val_cell_renderer_mode(data) ml_lookup_from_c (ml_table_cell_renderer_mode, data)
 #define Cell_renderer_mode_val(key) ml_lookup_to_c (ml_table_cell_renderer_mode, key)
 
-/* message_type : tags and macros */
-#define MLTAG_INFO	((value)(813432942*2+1))
-#define MLTAG_WARNING	((value)(161459772*2+1))
-#define MLTAG_QUESTION	((value)(3549990*2+1))
-#define MLTAG_ERROR	((value)(-250084440*2+1))
-
-extern const lookup_info ml_table_message_type[];
-#define Val_message_type(data) ml_lookup_from_c (ml_table_message_type, data)
-#define Message_type_val(key) ml_lookup_to_c (ml_table_message_type, key)
+extern const lookup_info ml_table_cell_renderer_accel_mode[];
+#define Val_cell_renderer_accel_mode(data) ml_lookup_from_c (ml_table_cell_renderer_accel_mode, data)
+#define Cell_renderer_accel_mode_val(key) ml_lookup_to_c (ml_table_cell_renderer_accel_mode, key)
 
 /* buttons_type : tags and macros */
 #define MLTAG_OK	((value)(17692*2+1))
@@ -580,6 +616,8 @@ extern const lookup_info ml_table_widget_flags[];
 #define MLTAG_STOCK	((value)(33832630*2+1))
 #define MLTAG_ICON_SET	((value)(-268575620*2+1))
 #define MLTAG_ANIMATION	((value)(-963813660*2+1))
+#define MLTAG_ICON_NAME	((value)(181530641*2+1))
+#define MLTAG_GICON	((value)(300343104*2+1))
 
 extern const lookup_info ml_table_image_type[];
 #define Val_image_type(data) ml_lookup_from_c (ml_table_image_type, data)
@@ -599,23 +637,14 @@ extern const lookup_info ml_table_file_chooser_action[];
 #define Val_file_chooser_action(data) ml_lookup_from_c (ml_table_file_chooser_action, data)
 #define File_chooser_action_val(key) ml_lookup_to_c (ml_table_file_chooser_action, key)
 
-/* tree_model_flags : tags and macros */
-#define MLTAG_ITERS_PERSIST	((value)(-339514704*2+1))
-#define MLTAG_LIST_ONLY	((value)(-402526163*2+1))
+/* file_chooser_confirmation : tags and macros */
+#define MLTAG_CONFIRM	((value)(269316320*2+1))
+#define MLTAG_ACCEPT_FILENAME	((value)(934303262*2+1))
+#define MLTAG_SELECT_AGAIN	((value)(864149629*2+1))
 
-extern const lookup_info ml_table_tree_model_flags[];
-#define Val_tree_model_flags(data) ml_lookup_from_c (ml_table_tree_model_flags, data)
-#define Tree_model_flags_val(key) ml_lookup_to_c (ml_table_tree_model_flags, key)
-
-/* tree_view_drop_position : tags and macros */
-#define MLTAG_BEFORE	((value)(-860553089*2+1))
-#define MLTAG_AFTER	((value)(462462460*2+1))
-#define MLTAG_INTO_OR_BEFORE	((value)(486315964*2+1))
-#define MLTAG_INTO_OR_AFTER	((value)(-475234977*2+1))
-
-extern const lookup_info ml_table_tree_view_drop_position[];
-#define Val_tree_view_drop_position(data) ml_lookup_from_c (ml_table_tree_view_drop_position, data)
-#define Tree_view_drop_position_val(key) ml_lookup_to_c (ml_table_tree_view_drop_position, key)
+extern const lookup_info ml_table_file_chooser_confirmation[];
+#define Val_file_chooser_confirmation(data) ml_lookup_from_c (ml_table_file_chooser_confirmation, data)
+#define File_chooser_confirmation_val(key) ml_lookup_to_c (ml_table_file_chooser_confirmation, key)
 
 /* file_filter_flags : tags and macros */
 #define MLTAG_FILENAME	((value)(-789594425*2+1))
@@ -636,6 +665,7 @@ extern const lookup_info ml_table_file_filter_flags[];
 #define MLTAG_TOOLITEM	((value)(584268907*2+1))
 #define MLTAG_SEPARATOR	((value)(752341061*2+1))
 #define MLTAG_ACCELERATOR	((value)(-53513845*2+1))
+#define MLTAG_POPUP_WITH_ACCELS	((value)(-492352015*2+1))
 
 extern const lookup_info ml_table_ui_manager_item_type[];
 #define Val_ui_manager_item_type(data) ml_lookup_from_c (ml_table_ui_manager_item_type, data)
@@ -644,7 +674,6 @@ extern const lookup_info ml_table_ui_manager_item_type[];
 /* assistant_page_type : tags and macros */
 #define MLTAG_CONTENT	((value)(424370457*2+1))
 #define MLTAG_INTRO	((value)(1007616588*2+1))
-#define MLTAG_CONFIRM	((value)(269316320*2+1))
 #define MLTAG_SUMMARY	((value)(12377862*2+1))
 #define MLTAG_PROGRESS	((value)(-542079059*2+1))
 
@@ -652,18 +681,11 @@ extern const lookup_info ml_table_assistant_page_type[];
 #define Val_assistant_page_type(data) ml_lookup_from_c (ml_table_assistant_page_type, data)
 #define Assistant_page_type_val(key) ml_lookup_to_c (ml_table_assistant_page_type, key)
 
-/* cell_renderer_accel_mode : tags and macros */
-#define MLTAG_OTHER	((value)(879009456*2+1))
+/* entry_icon_position : tags and macros */
+#define MLTAG_PRIMARY	((value)(55579554*2+1))
+#define MLTAG_SECONDARY	((value)(-577585324*2+1))
 
-extern const lookup_info ml_table_cell_renderer_accel_mode[];
-#define Val_cell_renderer_accel_mode(data) ml_lookup_from_c (ml_table_cell_renderer_accel_mode, data)
-#define Cell_renderer_accel_mode_val(key) ml_lookup_to_c (ml_table_cell_renderer_accel_mode, key)
-
-/* file_chooser_confirmation : tags and macros */
-#define MLTAG_ACCEPT_FILENAME	((value)(934303262*2+1))
-#define MLTAG_SELECT_AGAIN	((value)(864149629*2+1))
-
-extern const lookup_info ml_table_file_chooser_confirmation[];
-#define Val_file_chooser_confirmation(data) ml_lookup_from_c (ml_table_file_chooser_confirmation, data)
-#define File_chooser_confirmation_val(key) ml_lookup_to_c (ml_table_file_chooser_confirmation, key)
+extern const lookup_info ml_table_entry_icon_position[];
+#define Val_entry_icon_position(data) ml_lookup_from_c (ml_table_entry_icon_position, data)
+#define Entry_icon_position_val(key) ml_lookup_to_c (ml_table_entry_icon_position, key)
 
