@@ -182,6 +182,7 @@ class virtual tree_view_column_props = object
   val virtual obj : _ obj
   method set_alignment = set TreeViewColumn.P.alignment obj
   method set_clickable = set TreeViewColumn.P.clickable obj
+  method set_expand = set TreeViewColumn.P.expand obj
   method set_fixed_width = set TreeViewColumn.P.fixed_width obj
   method set_max_width = set TreeViewColumn.P.max_width obj
   method set_min_width = set TreeViewColumn.P.min_width obj
@@ -196,6 +197,7 @@ class virtual tree_view_column_props = object
     set {TreeViewColumn.P.widget with conv=GObj.conv_widget_option} obj
   method alignment = get TreeViewColumn.P.alignment obj
   method clickable = get TreeViewColumn.P.clickable obj
+  method expand = get TreeViewColumn.P.expand obj
   method fixed_width = get TreeViewColumn.P.fixed_width obj
   method max_width = get TreeViewColumn.P.max_width obj
   method min_width = get TreeViewColumn.P.min_width obj
@@ -219,6 +221,7 @@ class virtual tree_view_column_notify obj = object (self)
     ~prop ~callback
   method alignment = self#notify TreeViewColumn.P.alignment
   method clickable = self#notify TreeViewColumn.P.clickable
+  method expand = self#notify TreeViewColumn.P.expand
   method fixed_width = self#notify TreeViewColumn.P.fixed_width
   method max_width = self#notify TreeViewColumn.P.max_width
   method min_width = self#notify TreeViewColumn.P.min_width
