@@ -13,6 +13,7 @@ type stretch =
 type underline = [ `NONE | `SINGLE | `DOUBLE | `LOW ]
 type wrap_mode = [ `WORD | `CHAR | `WORD_CHAR ]
 type ellipsize_mode = [ `NONE | `START | `MIDDLE | `END ]
+type alignment = [ `LEFT | `CENTER | `RIGHT ]
 
 (**/**)
 
@@ -24,11 +25,12 @@ external _get_tables : unit ->
   * underline variant_table
   * wrap_mode variant_table
   * ellipsize_mode variant_table
+  * alignment variant_table
   = "ml_pango_get_tables"
 
 
-let style, weight, variant, stretch, underline, wrap_mode,
-    ellipsize_mode = _get_tables ()
+let style, weight, variant, stretch, underline, wrap_mode, ellipsize_mode,
+    alignment = _get_tables ()
 
 let style_conv = Gobject.Data.enum style
 let weight_conv = Gobject.Data.enum weight
@@ -37,3 +39,4 @@ let stretch_conv = Gobject.Data.enum stretch
 let underline_conv = Gobject.Data.enum underline
 let wrap_mode_conv = Gobject.Data.enum wrap_mode
 let ellipsize_mode_conv = Gobject.Data.enum ellipsize_mode
+let alignment_conv = Gobject.Data.enum alignment
