@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id: wrappers.h 1417 2008-09-10 15:38:57Z ben_99_9 $ */
+/* $Id$ */
 
 #ifndef _wrappers_
 #define _wrappers_
@@ -33,16 +33,29 @@
 #include <caml/mlvalues.h>
 #include <caml/fail.h>
 #include <caml/custom.h>
-CAMLextern char *young_start, *young_end; /* from minor_gc.h */
+#include <caml/minor_gc.h>
+#define Is_young_block(v) \
+  (Is_block(v) && (value*)(v) < young_end && (value*)(v) > young_start)
+
+#ifndef Bytes_val
+#define Bytes_val String_val
+#endif
 
 CAMLexport value copy_memblock_indirected (void *src, asize_t size);
 value alloc_memblock_indirected (asize_t size);
+CAMLexport value ml_alloc_custom(struct custom_operations * ops,
+                                 uintnat size, mlsize_t mem, mlsize_t max);
 CAMLprim value ml_some (value);
 value ml_cons (value, value);
 CAMLexport void ml_raise_null_pointer (void) Noreturn;
 CAMLexport value Val_pointer (void *);
 CAMLprim value copy_string_check (const char*);
 value copy_string_or_null (const char *);
+value Val_option_string (const char *s);
+
+value string_list_of_strv (const char * const *v);
+value string_list_of_strv2 (char **v);
+char ** strv_of_string_list (value list);
 
 CAMLprim value *ml_global_root_new (value v);
 CAMLexport void ml_global_root_destroy (void *data);
@@ -250,7 +263,8 @@ CAMLprim value cname##_bc (value *argv, int argn) \
 /* parameter conversion */
 #define Bool_ptr(x) ((long) x - 1)
 #define Char_val Int_val
-#define Float_val(x) ((float)Double_val(x))
+#define Float_val Double_val
+/* #define Float_val(x) ((float)Double_val(x)) */
 #define SizedString_val(x) String_val(x), string_length(x)
 
 #define Option_val(val,unwrap,default) \
@@ -282,7 +296,7 @@ static struct custom_operations ml_custom_##type = \
   custom_hash_default, custom_serialize_default, custom_deserialize_default };\
 CAMLprim value Val_##type (type *p) \
 { value ret; if (!p) ml_raise_null_pointer(); \
-  ret = alloc_custom (&ml_custom_##type, sizeof(value), adv, 1000); \
+  ret = ml_alloc_custom (&ml_custom_##type, sizeof(value), adv, 1000); \
   initialize (&Field(ret,1), (value) p); init(p); return ret; }
 
 #define Make_Val_final_pointer_ext(type, ext, init, final, adv) \
@@ -293,7 +307,7 @@ static struct custom_operations ml_custom_##type##ext = \
   custom_hash_default, custom_serialize_default, custom_deserialize_default };\
 CAMLprim value Val_##type##ext (type *p) \
 { value ret; if (!p) ml_raise_null_pointer(); \
-  ret = alloc_custom (&ml_custom_##type##ext, sizeof(value), adv, 1000); \
+  ret = ml_alloc_custom (&ml_custom_##type##ext, sizeof(value), adv, 1000); \
   initialize (&Field(ret,1), (value) p); init(p); return ret; }
 
 #define Make_Val_final_pointer_compare(type, init, comp, final, adv) \
@@ -306,7 +320,7 @@ static struct custom_operations ml_custom_##type = \
   custom_hash_default, custom_serialize_default, custom_deserialize_default };\
 CAMLprim value Val_##type (type *p) \
 { value ret; if (!p) ml_raise_null_pointer(); \
-  ret = alloc_custom (&ml_custom_##type, sizeof(value), adv, 1000); \
+  ret = ml_alloc_custom (&ml_custom_##type, sizeof(value), adv, 1000); \
   initialize (&Field(ret,1), (value) p); init(p); return ret; }
 
 #define Pointer_val(val) ((void*)Field(val,1))
@@ -356,6 +370,8 @@ CAMLprim int OptFlags_##conv (value list) \
 #define Val_optstring copy_string_or_null
 #define Optstring_val(v) (string_length(v) ? String_val(v) : (char*)NULL)
 #define Val_option(v,f) (v ? ml_some(f(v)) : Val_unit)
+#define Make_Val_option(T) \
+value Val_option_##T(T* v) { return Val_option(v,Val_##T); }
 
 #define Check_null(v) (v ? v : (ml_raise_null_pointer (), v))
 
